@@ -24,10 +24,6 @@ from bert4keras.models import build_transformer_model
 from bert4keras.tokenizers import Tokenizer
 from bert4keras.snippets import sequence_padding
 
-# collection
-m = Mongo()
-cache_bert = m.db['cache_bert']
-
 # BERT_DIR
 BERT_DIR = './chinese_simbert_L-12_H-768_A-12'
 fds_url = get_zk_config("/mipush/cfg")['fds_url']
@@ -78,6 +74,9 @@ def texts2vec(texts):
     return vecs
 
 
+# # collection
+# m = Mongo()
+# cache_bert = m.db['cache_bert']
 # def get_one_vec(**kwargs):
 #     text = kwargs.get('text', '默认')
 #     is_lite = kwargs.get('is_lite', '0')
